==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-radial-column-series.js <==
import * as tslib_1 from "tslib";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialColumnSeries } from "./RadialColumnSeries";
/**
 * Represents a IgxDataChartComponent radial column series.
 * Compare values across categories by using radial rectangles.
*/
var IgrRadialColumnSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrRadialColumnSeries, _super);
    function IgrRadialColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialColumnSeries.prototype.createImplementation = function () {
        return new RadialColumnSeries();
    };
    Object.defineProperty(IgrRadialColumnSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.oi;
        },
        set: function (v) {
            this.i.oi = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.oj;
        },
        set: function (v) {
            this.i.oj = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialColumnSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrRadialColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.ec();
        return (iv);
    };
    return IgrRadialColumnSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialColumnSeries };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-radial-column-series.js <==
import * as tslib_1 from "tslib";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialColumnSeries } from "./RadialColumnSeries";
/**
 * Represents a IgxDataChartComponent radial column series.
 * Compare values across categories by using radial rectangles.
*/
var IgrRadialColumnSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrRadialColumnSeries, _super);
    function IgrRadialColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialColumnSeries.prototype.createImplementation = function () {
        return new RadialColumnSeries();
    };
    Object.defineProperty(IgrRadialColumnSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.ok;
        },
        set: function (v) {
            this.i.ok = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.ol;
        },
        set: function (v) {
            this.i.ol = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialColumnSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrRadialColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.ed();
        return (iv);
    };
    return IgrRadialColumnSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialColumnSeries };
